@@ -76,6 +76,7 @@ class AdvancedInterfaceSwitcherMaemo5(StatusMenuItem):
           active += 1
         except Exception, e:
           loaded_list = '%s\n%s\nError: %s\n' % (loaded_list, iface, e)
+          #print e
           pass
       else:
         self.__interfaces[key] = None
@@ -133,9 +134,11 @@ class AdvancedInterfaceSwitcherMaemo5(StatusMenuItem):
     for child in children:
       self.__smi_box.remove(child)
     for iface in self.__available_ifaces:
-      iface_obj = self.__interfaces[iface.name.lower()]
-      if iface_obj:
-        self.__smi_box.pack_start(iface_obj.get_button())
+      name = iface.name.lower()
+      if name in self.__interfaces:
+        iface_obj = self.__interfaces[name]
+        if iface_obj:
+          self.__smi_box.pack_start(iface_obj.get_button())
 
   def __settings_button_clicked(self, button):
     button.get_toplevel().hide()
