@@ -19,7 +19,7 @@ import advifswlib.util.locale as locale
 __all__ = ['InterfaceState', 'AbstractInterface']
 
 class InterfaceState():
-  off, on, connected, connecting, disconnecting = range(5)
+  off, on, connected, connecting, disconnecting, none = range(6)
 
 class AbstractInterface():
 
@@ -67,8 +67,11 @@ class AbstractInterface():
   def __startup(self):
     self.__init_interfaces()
     self.__get_status()
-    self.__init_signals()
-    self.post_init()
+    if self.state['value'] == InterfaceState.none:
+      print 'not found'
+    else:
+      self.__init_signals()
+      self.post_init()
 
   def __create_button(self):
     with self.__processing:
@@ -262,7 +265,10 @@ class AbstractInterface():
 
   def __get_status(self):
     self.state['value'], self.state['mode'], self.state['strength'] = self.get_status()
-    self.__update_ui()
+    if self.state['value'] == InterfaceState.none:
+      raise RuntimeError('No interface')
+    else:
+      self.update()
 
   def update(self):
     self.__update_ui()
