@@ -17,7 +17,7 @@ class BTInterface(AbstractInterface):
 
   def init_state(self):
     self.interfaces = {'BlueZAdapter': ['org.bluez',
-                                        get_shell_command_output('dbus-send --system --dest=org.bluez --print-reply / org.bluez.Manager.DefaultAdapter | tail -1 | sed \'s/^.*"\\(.*\\)".*$/\\1/\' 2>/dev/null').replace('\n', ''),
+                                        self.get_adapter_path(),
                                         'org.bluez.Adapter',
                                         None,
                                         True],
@@ -26,6 +26,7 @@ class BTInterface(AbstractInterface):
                                         'org.bluez.Device',
                                         None,
                                         True]}
+    #print self.interfaces['BlueZAdapter'][1]
     self.state = {'name': self.name,
                   'dbus': {'on': {'signal_name': 'PropertyChanged',
                                   'dbus_interface': self.interfaces['BlueZAdapter'][2],
@@ -33,7 +34,10 @@ class BTInterface(AbstractInterface):
                            'connected': {'signal_name': 'PropertyChanged',
                                          'dbus_interface': self.interfaces['BlueZDevice'][2],
                                          'path': self.interfaces['BlueZDevice'][1],
-                                         'path_keyword': 'path'}
+                                         'path_keyword': 'path'},
+                           'adapter': {'signal_name': 'DefaultAdapterChanged',
+                                       'dbus_interface': 'org.bluez.Manager',
+                                       'path':'/'}
                           },
                   'images': ('ifsw_statusarea_bluetooth_off', 
                              'ifsw_statusarea_bluetooth_on', 
@@ -48,6 +52,17 @@ class BTInterface(AbstractInterface):
                   'mode': 0}
     self.connected_device = set()
 
+  def get_adapter_path(self):
+    return get_shell_command_output('dbus-send --system --dest=org.bluez --print-reply / org.bluez.Manager.DefaultAdapter | tail -1 | sed \'s/^.*"\\(.*\\)".*$/\\1/\' 2>/dev/null').replace('\n', '')
+
+  def process_signal_adapter(self, path):
+    path = str(path)
+    self.interfaces['BlueZAdapter'][1] = path
+    self.reinit_interface('BlueZAdapter', True)
+    self.state['dbus']['on']['path'] = path
+    self.reinit_signal('on')
+    return self.get_status()
+
   def process_signal_connected(self, prop, value, **kwargs):
     if str(prop) == 'Connected':
       device = kwargs['path'].replace('%s/' % self.interfaces['BlueZAdapter'][1], '')
