@@ -20,7 +20,9 @@ class GSMInterface(AbstractInterface):
                  'blocked_sim', 'sim_locked'),
                 ('activation_failed', 'selection_failed'),
                 ('online','sim_ready', 'initialize'),
-                ('activation_pending',)]
+                ('activation_pending',),
+                tuple(),
+                ('simless',)]
 
   #'sim_mode_als2' - what's that...
   #status_on = (3,4,5,9,10,11)
@@ -59,16 +61,18 @@ class GSMInterface(AbstractInterface):
                   'images': ('ifsw_statusarea_cell_off',
                              'ifsw_statusarea_cell_signal_0',
                              'ifsw_statusarea_cell_signal_5',
-                             'ifsw_statusarea_cell_connecting'),
+                             'ifsw_statusarea_cell_connecting'
+                             'ifsw_statusarea_cell_connecting',
+                             'ifsw_statusarea_cell_off'),
                   'images_st': ('ifsw_statusarea_cell_signal_0',
                                 'ifsw_statusarea_cell_signal_1',
                                 'ifsw_statusarea_cell_signal_2',
                                 'ifsw_statusarea_cell_signal_3',
                                 'ifsw_statusarea_cell_signal_4',
                                 'ifsw_statusarea_cell_signal_5'),
-                  'text': ['Off', 'On', '<>', 'Connecting'],
-                  'show': (True, True, False, True),
-                  'banner': (True, True, True, True),
+                  'text': ['Off', 'On', '<>', 'Connecting', 'Disconnecting', 'None'],
+                  'show': (True, True, False, True, True, False),
+                  'banner': (True, True, True, True, True, False),
                   'value': InterfaceState.off,
                   'strength': 0,
                   'modes': ('gsm-3g+gsm', 'gsm-2g', 'gsm-3g'),
@@ -83,7 +87,9 @@ class GSMInterface(AbstractInterface):
       value = str(value)
       result = None
       strength = None
-      if value in self.ssc_status[InterfaceState.off]:
+      if value in self.ssc_status[InterfaceState.none]:
+        result = InterfaceState.none
+      elif value in self.ssc_status[InterfaceState.off]:
         result = InterfaceState.off
       elif value in self.ssc_status[InterfaceState.connecting]:
         result = InterfaceState.connecting
