@@ -2,5 +2,5 @@
 ifconfig wlan0 0.0.0.0
 ifconfig wlan0 down
 sleep 1
-sudo stop wlancond
+stop wlancond
 /usr/bin/advifsw/exec.sh ./post-down
\ No newline at end of file
